# 3.4 文本处理

> 原文：[Working with text](http://matplotlib.org/users/index_text.html)

> 译者：[飞龙](https://github.com/)

> 协议：[CC BY-NC-SA 4.0](http://creativecommons.org/licenses/by-nc-sa/4.0/)

## 引言

matplotlib 具有优秀的文本支持，包括数学表达式，光栅和向量输出的 truetype 支持，任意旋转的换行分隔文本和 unicode 支持。 因为我们直接在输出文档中嵌入字体，例如 postscript 或 PDF，你在屏幕上看到的也是你在打印件中得到的。 freetype2 可产生非常漂亮，抗锯齿的字体，即使在小光栅尺寸下看起来也不错。 matplotlib 拥有自己的`matplotlib.font_manager`，感谢 Paul Barrett，他实现了一个跨平台，符合 W3C 标准的字体查找算法。

你可以完全控制每个文本属性（字体大小，字体重量，文本位置和颜色等），并在`rc`文件中设置合理的默认值。 并且对于那些对数学或科学图像感兴趣的人，matplotlib 实现了大量的 TeX 数学符号和命令，来支持你图中任何地方放置数学表达式。

## 基本的文本命令

### text


在`Axes`的任意位置添加文本。

命令式：[`matplotlib.pyplot.text`](http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.text)，面向对象：[`matplotlib.axes.Axes.text`](http://matplotlib.org/api/axes_api.html#matplotlib.axes.Axes.text)。


### xlabel

向 x 轴添加轴标签。

命令式：[`matplotlib.pyplot.xlabel`](http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.xlabel)，面向对象：[`matplotlib.axes.Axes.set_xlabel`](http://matplotlib.org/api/axes_api.html#matplotlib.axes.Axes.set_xlabel)。

### ylabel

向 y 轴添加轴标签。

命令式：[`matplotlib.pyplot.ylabel`](http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.ylabel)，面向对象：[`matplotlib.axes.Axes.set_ylabel`](http://matplotlib.org/api/axes_api.html#matplotlib.axes.Axes.set_ylabel)。

### title

向`Axes`添加标题。

命令式：[`matplotlib.pyplot.title`](http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.title)，面向对象：[`matplotlib.axes.Axes.set_title`](http://matplotlib.org/api/axes_api.html#matplotlib.axes.Axes.set_title)。

### figtext

向`Figure`的任意位置添加文本。

命令式：[`matplotlib.pyplot.figtext`](http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.figtext)，面向对象：[`matplotlib.figure.Figure.text`](http://matplotlib.org/api/figure_api.html#matplotlib.figure.Figure.text)。

### suptitle

向`Figure`添加标题。

命令式：[`matplotlib.pyplot.suptitle`](http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.suptitle)，面向对象：[`matplotlib.figure.Figure.suptitle`](http://matplotlib.org/api/figure_api.html#matplotlib.figure.Figure.suptitle)。

### annotate

向`Axes`添加标注，带有可选的箭头。

命令式：[`matplotlib.pyplot.annotate`](http://matplotlib.org/api/pyplot_api.html#matplotlib.pyplot.annotate)，面向对象：[`matplotlib.axes.Axes.annotate`](http://matplotlib.org/api/axes_api.html#matplotlib.axes.Axes.annotate)。

所有这些函数创建并返回一个`matplotlib.text.Text()`实例，它可以配置各种字体和其他属性。 下面的示例在实战中展示所有这些命令。

```py
# -*- coding: utf-8 -*-
import matplotlib.pyplot as plt

fig = plt.figure()
fig.suptitle('bold figure suptitle', fontsize=14, fontweight='bold')

ax = fig.add_subplot(111)
fig.subplots_adjust(top=0.85)
ax.set_title('axes title')

ax.set_xlabel('xlabel')
ax.set_ylabel('ylabel')

ax.text(3, 8, 'boxed italics text in data coords', style='italic',
        bbox={'facecolor':'red', 'alpha':0.5, 'pad':10})

ax.text(2, 6, r'an equation: $E=mc^2$', fontsize=15)

ax.text(3, 2, u'unicode: Institut f\374r Festk\366rperphysik')

ax.text(0.95, 0.01, 'colored text in axes coords',
        verticalalignment='bottom', horizontalalignment='right',
        transform=ax.transAxes,
        color='green', fontsize=15)


ax.plot([2], [1], 'o')
ax.annotate('annotate', xy=(2, 1), xytext=(3, 4),
            arrowprops=dict(facecolor='black', shrink=0.05))

ax.axis([0, 10, 0, 10])

plt.show()
```

![](http://matplotlib.org/_images/text_commands.png)

## 文本属性及布局

`matplotlib.text.Text`实例有各种属性，可以通过关键字参数配置文本命令（例如，`title()`，`xlabel()`和`text()`）。


| 属性 | 值类型 |
| --- | --- |
| alpha | 浮点 |
| backgroundcolor | 任何 matplotlib 颜色 |
| bbox | rectangle prop dict plus key 'pad' which is a pad in points |
| clip_box | `matplotlib.transform.Bbox` 实例 |
| clip_on | `[True / False]` |
| clip_path | `Path` 实例和 `Transform` 实例，`Patch` |
| color | 任何 matplotlib 颜色 |
| family | `[ 'serif' / 'sans-serif' / 'cursive' / 'fantasy' / 'monospace' ]` |
| fontproperties | `matplotlib.font_manager.FontProperties` 实例 |
| horizontalalignment or ha | `[ 'center' / 'right' / 'left' ]` |
| label | 任何字符串 |
| linespacing | 浮点 |
| multialignment | `['left' / 'right' / 'center' ]` |
| name or fontname | 字符串，例如 `['Sans' / 'Courier' / 'Helvetica' ...]` |
| picker | [`None` / 浮点 / 布尔值 / 可调用对象]` |
| position | `(x,y)` |
| rotation | [ 角度制的角度 / 'vertical' / 'horizontal' |
| size or fontsize | [ 点的尺寸 | 相对尺寸，例如 `['smaller', 'x-large' ]` |
| style or fontstyle | `[ 'normal' / 'italic' / 'oblique']` |
| text | 字符串或任何可使用`'%s'`打印的东西 |
| transform | `matplotlib.transform` 实例 |
| variant | `[ 'normal' / 'small-caps' ]` |
| verticalalignment or va | `[ 'center' / 'top' / 'bottom' / 'baseline' ]` |
| visible | `[True / False]` |
| weight or fontweight | `[ 'normal' / 'bold' / 'heavy' / 'light' / 'ultrabold' / 'ultralight']` |
| x | 浮点 |
| y | 浮点 |
| zorder | 任意数值 |

你可以使用对齐参数`horizontalalignment`，`verticalalignment`和`multialignment`来布置文本。 `horizontalalignment`控制文本的`x`位置参数表示文本边界框的左边，中间或右边。 `verticalalignment`控制文本的`y`位置参数表示文本边界框的底部，中心或顶部。 `multialignment`，仅对于换行符分隔的字符串，控制不同的行是左，中还是右对齐。 这里是一个使用`text()`命令显示各种对齐方式的例子。 在整个代码中使用`transform = ax.transAxes`，表示坐标相对于轴边界框给出，其中`0,0`是轴的左下角，`1,1`是右上角。

```py
import matplotlib.pyplot as plt
import matplotlib.patches as patches

# build a rectangle in axes coords
left, width = .25, .5
bottom, height = .25, .5
right = left + width
top = bottom + height

fig = plt.figure()
ax = fig.add_axes([0,0,1,1])

# axes coordinates are 0,0 is bottom left and 1,1 is upper right
p = patches.Rectangle(
    (left, bottom), width, height,
    fill=False, transform=ax.transAxes, clip_on=False
    )

ax.add_patch(p)

ax.text(left, bottom, 'left top',
        horizontalalignment='left',
        verticalalignment='top',
        transform=ax.transAxes)

ax.text(left, bottom, 'left bottom',
        horizontalalignment='left',
        verticalalignment='bottom',
        transform=ax.transAxes)

ax.text(right, top, 'right bottom',
        horizontalalignment='right',
        verticalalignment='bottom',
        transform=ax.transAxes)

ax.text(right, top, 'right top',
        horizontalalignment='right',
        verticalalignment='top',
        transform=ax.transAxes)

ax.text(right, bottom, 'center top',
        horizontalalignment='center',
        verticalalignment='top',
        transform=ax.transAxes)

ax.text(left, 0.5*(bottom+top), 'right center',
        horizontalalignment='right',
        verticalalignment='center',
        rotation='vertical',
        transform=ax.transAxes)

ax.text(left, 0.5*(bottom+top), 'left center',
        horizontalalignment='left',
        verticalalignment='center',
        rotation='vertical',
        transform=ax.transAxes)

ax.text(0.5*(left+right), 0.5*(bottom+top), 'middle',
        horizontalalignment='center',
        verticalalignment='center',
        fontsize=20, color='red',
        transform=ax.transAxes)

ax.text(right, 0.5*(bottom+top), 'centered',
        horizontalalignment='center',
        verticalalignment='center',
        rotation='vertical',
        transform=ax.transAxes)

ax.text(left, top, 'rotated\nwith newlines',
        horizontalalignment='center',
        verticalalignment='center',
        rotation=45,
        transform=ax.transAxes)

ax.set_axis_off()
plt.show()
```

![](http://matplotlib.org/_images/text_layout.png)

## 编写数学表达式

你可以在任何 matplotlib 文本字符串中使用子 TeX 标记，将它放在一对美元符号（`$`）内。

注意，你不需要安装 TeX，因为 matplotlib 提供了自己的 TeX 表达式解析器，布局引擎和字体。 布局引擎是 Donald Knuth 的 TeX 中的布局算法的一种相当直接的适配版，所以质量是相当不错的（matplotlib 还为那些想要调用 TeX 生成文本的人提供一个`usetex`选项（参见[使用 LaTeX 渲染文本](http://matplotlib.org/users/usetex.html#usetex-tutorial) ）。

任何文本元素都可以使用数学文本。 你应该使用原始字符串（在引号前面加一个`'r'`），并用美元符号（`$`）包围数学文本，如 TeX。 常规文本和数学文本可以在同一个字符串内交错。 Mathtext 可以使用 Computer Modern 字体（来自 (La)TeX），STIX 字体（为与 Times 混合使用而设计）或你提供的 Unicode 字体。 可以使用自定义变量`mathtext.fontset`选择 mathtext 字体（请参阅[自定义 matplotlib](http://matplotlib.org/users/customizing.html#customizing-matplotlib)）

> 注意

> 在Python的  『narrow』  构建中，如果使用 STIX 字体，你还应该将`ps.fonttype`和`pdf.fonttype`设置为 3（默认值），而不是 42。否则一些字符将不可见。

下面是个简单的例子：

```py
# plain text
plt.title('alpha > beta')
```

生成`alpha > beta`。

但是这个：

```py
# math text
plt.title(r'$\alpha > \beta$')
```

生成 ![](http://matplotlib.org/_images/mathmpl/math-3ba37e0517.png)。

> 注意

> Mathtext 应该放在一对美元符号（`$`）之间。 为了易于显示货币值，例如`$ 100.00`，如果整个字符串中存在单个美元符号，则它将被逐字显示为美元符号。 这是常规 TeX 的一个小改变，其中非数学文本中的美元符号必须被转义（`'$'`）。

> 注意

> 虽然一对美元符号（`$`）内的语法是 TeX 风格的，但是外面的文本不是。 特别是，字符：

> ```
> # $ % & ~ _ ^ \ { } \( \) \[ \]
> ```

> 在 TeX 中的数学模式之外有特殊的意义。 因此，根据`rcParam text.usetex`标志这些字符的表现有所不同。 更多信息请参阅[`usetex`教程](http://matplotlib.org/users/usetex.html#usetex-tutorial)。

### 下标和上标

为了制作下标和上标，使用`_`或者`^`符号：

```py
r'$\alpha_i > \beta_i$'
```

![](http://matplotlib.org/_images/mathmpl/math-e2db32b4d0.png)

一些符号会自动将它们的下标或上标放在操作符的底部或顶部，例如，为了编写 0 到无穷的 ![](http://matplotlib.org/_images/mathmpl/math-ccea9f4e30.png) 的和，你可以：

```py
r'$\sum_{i=0}^\infty x_i$'
```

![](http://matplotlib.org/_images/mathmpl/math-a3ca6be911.png)

### 分数、二项式和堆叠数

可以使用`\frac{}{}`，`\binomial{}{}`和`\stackrel{}{}`命令分别创建分数，二项式和堆叠数字：

```py
r'$\frac{3}{4} \binom{3}{4} \stackrel{3}{4}$'
```

产生

![](http://matplotlib.org/_images/mathmpl/math-3025afbc71.png)

分数可以任意嵌套：

```py
r'$\frac{5 - \frac{1}{x}}{4}$'
```

产生

![](http://matplotlib.org/_images/mathmpl/math-2e885fe67f.png)

请注意，在分数周围放置圆括号和花括号需要特别注意。 这种明显的方式会产生太小的括号：

```py
r'$(\frac{5 - \frac{1}{x}}{4})$'
```

![](http://matplotlib.org/_images/mathmpl/math-07b17ba8f6.png)

解决方案是在括号前面加上`\left`和`\right`以通知解析器这些括号包含整个对象：

```py
r'$\left(\frac{5 - \frac{1}{x}}{4}\right)$'
```

![](http://matplotlib.org/_images/mathmpl/math-9d267a8c3c.png)

### 根式

根式可以有`\sqrt[]{}`产生，例如：

```py
r'$\sqrt{2}$'
```

![](http://matplotlib.org/_images/mathmpl/math-f151e9b6c6.png)

方括号内可以（可选地）设置任何底数。 请注意，底数必须是一个简单的表达式，并且不能包含布局命令，如分数或上下标：

```py
r'$\sqrt[3]{x}$'
```

![](http://matplotlib.org/_images/mathmpl/math-6b6cc30aef.png)

### 字体

用于数学符号的默认字体是斜体。

> 注意

> 此默认值可以使用`mathtext.default` `rcParam`更改。 这是非常有用的，例如，通过将其设置为`regular`，使用与常规非数学文本相同的字体作为数学文本。

为了修改字体，例如，以罗马字体编写`sin`，使用字体命令来闭合文本：

```py
r'$s(t) = \mathcal{A}\mathrm{sin}(2 \omega t)$'
```

![](http://matplotlib.org/_images/mathmpl/math-c8056d47b3.png)


这里`s`和`t`是斜体（默认）的变量，`sin`是罗马字体，振幅`A`是书法字体。 注意在上面的例子中，`A`和`sin`之间的间距被挤压。 你可以使用间距命令在它们之间添加一些空格：

```
s(t) = \mathcal{A}\/\sin(2 \omega t)
```

![](http://matplotlib.org/_images/mathmpl/math-44f45b7160.png)

所有字体的可用选项为：

| 命令 | 结果 |
| --- | --- |
| `\mathrm{Roman}` | ![](http://matplotlib.org/_images/mathmpl/math-89f87a2f0c.png) |
| `\mathit{Italic}` | ![](http://matplotlib.org/_images/mathmpl/math-968de0e26b.png) |
| `\mathtt{Typewriter}` | ![](http://matplotlib.org/_images/mathmpl/math-ca3f612baa.png) |
| `\mathcal{CALLIGRAPHY}` | ![](http://matplotlib.org/_images/mathmpl/math-1f62587cf2.png) |

使用 STIX 字体时，你也可以选择：

| 命令 | 结果 |
| --- | --- |
| `\mathbb{blackboard}` | ![](http://matplotlib.org/_images/mathmpl/math-a12676f03f.png) |
| `\mathrm{\mathbb{blackboard}}` | ![](http://matplotlib.org/_images/mathmpl/math-014e74dc81.png) |
| `\mathfrak{Fraktur}` | ![](http://matplotlib.org/_images/mathmpl/math-4f55ade322.png) |
| `\mathsf{sansserif}` | ![](http://matplotlib.org/_images/mathmpl/math-e9444fe0c8.png) |
| `\mathrm{\mathsf{sansserif}}` | ![](http://matplotlib.org/_images/mathmpl/math-c3a13bbc63.png) |
| `\mathcircled{circled}` | ![](http://matplotlib.org/_images/mathmpl/math-e82daa3fb7.png) |

还有三个全局『字体集』可供选择，它们使用`matplotlibrc`中的`mathtext.fontset`参数进行选择。

`cm`: Computer Modern (TeX)

![](http://matplotlib.org/_images/cm_fontset.png)

`stix`: STIX （为和 Times 混合使用而设计）

![](http://matplotlib.org/_images/stix_fontset.png)

`stixsans`: STIX sans-serif

![](http://matplotlib.org/_images/stixsans_fontset.png)

此外，你可以使用`\mathdefault{...}`或其别名`\mathregular{...}`来使用用于 mathtext 之外的常规文本的字体。 这种方法有一些限制，最明显的是，可以使用很少的符号，但可用于将数学表达式与图中的其他文本混合。

### 自定义字体

mathtext 还提供了一种对数学公式使用自定义字体的方法。 这种方法使用起来相当棘手，应该看做为有耐心的用户准备的试验特性。 通过将`rcParam mathtext.fontset`设置为`custom`，你可以设置以下参数，这些参数控制用于特定数学字符集的字体文件。

| 参数 | 相当于 |
| --- | --- |
| `mathtext.it` | `\mathit{}` 默认斜体 |
| `mathtext.rm` | `\mathrm{}` 罗马字体（upright） |
| `mathtext.tt` | `\mathtt{}` 打字机（monospace） |
| `mathtext.bf` | `\mathbf{}` 粗体 |
| `mathtext.cal` | `\mathcal{}` 书法 |
| `mathtext.sf` | `\mathsf{}` sans-serif |

每个参数应该设置为`fontconfig`字体描述符（在尚未编写的字体章节中定义）。

所使用的字体应该具有 Unicode 映射，以便找到任何非拉丁字符，例如希腊语。 如果要使用未包含在自定义字体中的数学符号，可以将`rcParam mathtext.fallback_to_cm`设置为`True`，这将导致自定义字体中找不到特定字符时，数学文本系统使用默认的 Computer Modern 字体中的字符。

请注意，Unicode 中规定的数学字形随时间而演进，许多字体的字形对于 mathtext 可能不在正确位置。

### 重音符号

重音命令可以位于任何符号之前，在其上添加重音。 他们中的一些些拥有较长和较短的形式。

| 命令 | 结果 |
| --- | --- |
| `\acute a` 或 `\'a` | ![](http://matplotlib.org/_images/mathmpl/math-fac074d098.png) |
| `\bar a` | ![](http://matplotlib.org/_images/mathmpl/math-b7c546c13f.png) |
| `\breve a` | ![](http://matplotlib.org/_images/mathmpl/math-88814f8d66.png) |
| `\ddot a` 或 `\"a` | ![](http://matplotlib.org/_images/mathmpl/math-adb99bedc4.png) |
| `\dot a` 或 `\.a` | ![](http://matplotlib.org/_images/mathmpl/math-b5496f6786.png) |
| `\grave a` 或 `\`a` | ![](http://matplotlib.org/_images/mathmpl/math-54cbc28bce.png) |
| `\hat a` 或 `\^a` | ![](http://matplotlib.org/_images/mathmpl/math-16da2c10a1.png) |
| `\tilde a` 或 `\~a` | ![](http://matplotlib.org/_images/mathmpl/math-3a8b2e99d6.png) |
| `\vec a` | ![](http://matplotlib.org/_images/mathmpl/math-be2ea18bef.png) |
| `\overline{abc}` | ![](http://matplotlib.org/_images/mathmpl/math-75e95f3f2b.png) |

另外有两个特殊的重音符号，可以自动调整为符号的宽度：

| 命令 | 结果 |
| --- | --- |
| `\widehat{xyz}` | ![](http://matplotlib.org/_images/mathmpl/math-8e4b9eb82b.png) |
| `\widetilde{xyz}` | ![](http://matplotlib.org/_images/mathmpl/math-bf67fbdaae.png) |

当把重音放在小写的`i`和`j`上时应该小心。 注意下面的`\imath`用来避免`i`上额外的点：

```py
r"$\hat i\ \ \hat \imath$"
```

![](http://matplotlib.org/_images/mathmpl/math-80117b16d3.png)

### 符号

你也可以使用更大量的 TeX 符号，比如`\infty`，`\leftarrow`，`\sum`，`\int`。


| 小写希腊字母 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-5149852f08.png) `\alpha` | ![](http://matplotlib.org/_images/mathmpl/math-59ed813421.png) `\beta` | ![](http://matplotlib.org/_images/mathmpl/math-7d54d13fc9.png) `\chi` | ![](http://matplotlib.org/_images/mathmpl/math-e15357ad29.png) `\delta` | ![](http://matplotlib.org/_images/mathmpl/math-41188a0c1b.png) `\digamma` |
| ![](http://matplotlib.org/_images/mathmpl/math-21b6ff3aa7.png) `\epsilon` | ![](http://matplotlib.org/_images/mathmpl/math-0fa258552e.png) `\eta` | ![](http://matplotlib.org/_images/mathmpl/math-ae65c1de79.png) `\gamma` | ![](http://matplotlib.org/_images/mathmpl/math-ff6a67483e.png) `\iota` | ![](http://matplotlib.org/_images/mathmpl/math-436efe52d1.png) `\kappa` |
| ![](http://matplotlib.org/_images/mathmpl/math-3642ca147d.png) `\lambda` | ![](http://matplotlib.org/_images/mathmpl/math-3488de1d0a.png) `\mu` | ![](http://matplotlib.org/_images/mathmpl/math-79a0df421c.png) `\nu` | ![](http://matplotlib.org/_images/mathmpl/math-b555ccd28d.png) `\omega` | ![](http://matplotlib.org/_images/mathmpl/math-e22cc525ec.png) `\phi` |
| ![](http://matplotlib.org/_images/mathmpl/math-2c7a9dac6d.png) `\pi` | ![](http://matplotlib.org/_images/mathmpl/math-3fc9142b1d.png) `\psi` | ![](http://matplotlib.org/_images/mathmpl/math-f2e3547a85.png) `\rho` | ![](http://matplotlib.org/_images/mathmpl/math-293c147d21.png) `\sigma` | ![](http://matplotlib.org/_images/mathmpl/math-f970af607c.png) `\tau` |
| ![](http://matplotlib.org/_images/mathmpl/math-5dc8912759.png) `\theta` | ![](http://matplotlib.org/_images/mathmpl/math-ac7cfff3a1.png) `\upsilon` | ![](http://matplotlib.org/_images/mathmpl/math-a88976d8dd.png) `\varepsilon` | ![](http://matplotlib.org/_images/mathmpl/math-67a8f5ca79.png) `\varkappa` | ![](http://matplotlib.org/_images/mathmpl/math-a79325da6f.png) `\varphi` |
| ![](http://matplotlib.org/_images/mathmpl/math-5e94f6d1ef.png) `\varpi` | ![](http://matplotlib.org/_images/mathmpl/math-d6c1d2bb14.png) `\varrho` | ![](http://matplotlib.org/_images/mathmpl/math-92fc1ff85f.png) `\varsigma` | ![](http://matplotlib.org/_images/mathmpl/math-d11bf19a50.png) `\vartheta` | ![](http://matplotlib.org/_images/mathmpl/math-1859062b14.png) `\xi` |
| ![](http://matplotlib.org/_images/mathmpl/math-d51bb4d6d4.png) `\zeta` |

| 大写希腊字母 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-e3168b0fff.png) `\Delta` | ![](http://matplotlib.org/_images/mathmpl/math-4eacc6ba71.png) `\Gamma` | ![](http://matplotlib.org/_images/mathmpl/math-a57791e0e2.png) `\Lambda` | ![](http://matplotlib.org/_images/mathmpl/math-28d3e90e31.png) `\Omega` | ![](http://matplotlib.org/_images/mathmpl/math-cebfe4186d.png) `\Phi` | ![](http://matplotlib.org/_images/mathmpl/math-3b938a5601.png) `\Pi` |
| ![](http://matplotlib.org/_images/mathmpl/math-d44376b8c3.png) `\Psi` | ![](http://matplotlib.org/_images/mathmpl/math-076bf05243.png) `\Sigma` | ![](http://matplotlib.org/_images/mathmpl/math-98c28d2d1b.png) `\Theta` | ![](http://matplotlib.org/_images/mathmpl/math-43a44ec8e4.png) `\Upsilon` | ![](http://matplotlib.org/_images/mathmpl/math-376450e92a.png) `\Xi` | ![](http://matplotlib.org/_images/mathmpl/math-ab04245089.png) `\mho` |
| ![](http://matplotlib.org/_images/mathmpl/math-9544659959.png) `\nabla` |

| 希伯来文 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-d115134b0c.png) `\aleph` | ![](http://matplotlib.org/_images/mathmpl/math-b1d46891d0.png) `\beth` | ![](http://matplotlib.org/_images/mathmpl/math-ad0c7d5fd3.png) `\daleth` | ![](http://matplotlib.org/_images/mathmpl/math-4a68c72624.png) `\gimel` |

| 分隔符 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-9d750cc7d9.png) `/` | ![](http://matplotlib.org/_images/mathmpl/math-1f9db75fdb.png) `[` | ![](http://matplotlib.org/_images/mathmpl/math-0c8ba18b43.png) `\Downarrow` | ![](http://matplotlib.org/_images/mathmpl/math-d00ab41d80.png) `\Uparrow` | ![](http://matplotlib.org/_images/mathmpl/math-2480720752.png) `\Vert` | ![](http://matplotlib.org/_images/mathmpl/math-b6a35dc0d4.png) `\backslash` |
| ![](http://matplotlib.org/_images/mathmpl/math-56b7078922.png) `\downarrow` | ![](http://matplotlib.org/_images/mathmpl/math-46c392f788.png) `\langle` | ![](http://matplotlib.org/_images/mathmpl/math-6c35839641.png) `\lceil` | ![](http://matplotlib.org/_images/mathmpl/math-145ca7a5e7.png) `\lfloor` | ![](http://matplotlib.org/_images/mathmpl/math-554199c05b.png) `\llcorner` | ![](http://matplotlib.org/_images/mathmpl/math-057e1a984d.png) `\lrcorner` |
| ![](http://matplotlib.org/_images/mathmpl/math-ef94320557.png) `\rangle` | ![](http://matplotlib.org/_images/mathmpl/math-cbd4824a55.png) `\rceil` | ![](http://matplotlib.org/_images/mathmpl/math-c8d83de344.png) `\rfloor` | ![](http://matplotlib.org/_images/mathmpl/math-de64de5819.png) `\ulcorner` | ![](http://matplotlib.org/_images/mathmpl/math-f1bfb0bbf7.png) `\uparrow` | ![](http://matplotlib.org/_images/mathmpl/math-4f8107394b.png) `\urcorner` |
| ![](http://matplotlib.org/_images/mathmpl/math-e12e277d39.png) `\vert` | ![](http://matplotlib.org/_images/mathmpl/math-f81f19a962.png) `\{` | ![](http://matplotlib.org/_images/mathmpl/math-ee61bb7cf9.png) `\|` | ![](http://matplotlib.org/_images/mathmpl/math-19097cff83.png) `\}` | ![](http://matplotlib.org/_images/mathmpl/math-d35c7fd4db.png) `]` | ![](http://matplotlib.org/_images/mathmpl/math-dfa04fb947.png) `|` |

| 大型符号 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-db9b9e0126.png) `\bigcap` | ![](http://matplotlib.org/_images/mathmpl/math-52ee117ecd.png) `\bigcup` | ![](http://matplotlib.org/_images/mathmpl/math-a31bc74ee2.png) `\bigodot` | ![](http://matplotlib.org/_images/mathmpl/math-011efae7a0.png) `\bigoplus` | ![](http://matplotlib.org/_images/mathmpl/math-e8cf7f5844.png) `\bigotimes` |
| ![](http://matplotlib.org/_images/mathmpl/math-8f896d9410.png) `\biguplus` | ![](http://matplotlib.org/_images/mathmpl/math-1de8afe642.png) `\bigvee` | ![](http://matplotlib.org/_images/mathmpl/math-888740ee66.png) `\bigwedge` | ![](http://matplotlib.org/_images/mathmpl/math-1bb3130224.png) `\coprod` | ![](http://matplotlib.org/_images/mathmpl/math-1610e87ea8.png) `\int` |
| ![](http://matplotlib.org/_images/mathmpl/math-ce75170225.png) `\oint` | ![](http://matplotlib.org/_images/mathmpl/math-e661b1289d.png) `\prod` | ![](http://matplotlib.org/_images/mathmpl/math-f6fb720d82.png) `\sum` |

| 标准函数名称 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-a174a79fa7.png) `\Pr` | ![](http://matplotlib.org/_images/mathmpl/math-c7d2b9a8fd.png) `\arccos` | ![](http://matplotlib.org/_images/mathmpl/math-bab33d6e68.png) `\arcsin` | ![](http://matplotlib.org/_images/mathmpl/math-f8ee41a28a.png) `\arctan` |
| ![](http://matplotlib.org/_images/mathmpl/math-510e2aecba.png) `\arg` | ![](http://matplotlib.org/_images/mathmpl/math-a539c63e58.png) `\cos` | ![](http://matplotlib.org/_images/mathmpl/math-46d99aa165.png) `\cosh` | ![](http://matplotlib.org/_images/mathmpl/math-06c793e494.png) `\cot` |
| ![](http://matplotlib.org/_images/mathmpl/math-993151c5de.png) `\coth` | ![](http://matplotlib.org/_images/mathmpl/math-c72f36312c.png) `\csc` | ![](http://matplotlib.org/_images/mathmpl/math-efdcd0e7c3.png) `\deg` | ![](http://matplotlib.org/_images/mathmpl/math-a4f974e6ac.png) `\det` |
| ![](http://matplotlib.org/_images/mathmpl/math-4ceaca4089.png) `\dim` | ![](http://matplotlib.org/_images/mathmpl/math-9b8a721035.png) `\exp` | ![](http://matplotlib.org/_images/mathmpl/math-705a921d5a.png) `\gcd` | ![](http://matplotlib.org/_images/mathmpl/math-ec200f4f3a.png) `\hom` |
| ![](http://matplotlib.org/_images/mathmpl/math-d78d7b5c1b.png) `\inf` | ![](http://matplotlib.org/_images/mathmpl/math-9c3c23a23d.png) `\ker` | ![](http://matplotlib.org/_images/mathmpl/math-0c0d015405.png) `\lg` | ![](http://matplotlib.org/_images/mathmpl/math-441aa359eb.png) `\lim` |
| ![](http://matplotlib.org/_images/mathmpl/math-2f010c89dd.png) `\liminf` | ![](http://matplotlib.org/_images/mathmpl/math-a9a0109ea9.png) `\limsup` | ![](http://matplotlib.org/_images/mathmpl/math-a5edc7016a.png) `\ln` | ![](http://matplotlib.org/_images/mathmpl/math-e5cdb1d314.png) `\log` |
| ![](http://matplotlib.org/_images/mathmpl/math-fb64cdd50f.png) `\max` | ![](http://matplotlib.org/_images/mathmpl/math-bf7d25e347.png) `\min` | ![](http://matplotlib.org/_images/mathmpl/math-a0b5414d31.png) `\sec` | ![](http://matplotlib.org/_images/mathmpl/math-d8d19f17ef.png) `\sin` |
| ![](http://matplotlib.org/_images/mathmpl/math-fce9663ad9.png) `\sinh` | ![](http://matplotlib.org/_images/mathmpl/math-358f2a2131.png) `\sup` | ![](http://matplotlib.org/_images/mathmpl/math-fb3512b848.png) `\tan` | ![](http://matplotlib.org/_images/mathmpl/math-8e6df07c24.png) `\tanh` |

| 二元运算符和关系符号 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-f610b8e469.png) `\Bumpeq` | ![](http://matplotlib.org/_images/mathmpl/math-2a327a85e8.png) `\Cap` | ![](http://matplotlib.org/_images/mathmpl/math-0fbbe481d0.png) `\Cup` |
| ![](http://matplotlib.org/_images/mathmpl/math-2303577dee.png) `\Doteq` | ![](http://matplotlib.org/_images/mathmpl/math-70e89758da.png) `\Join` | ![](http://matplotlib.org/_images/mathmpl/math-3d85215bfa.png) `\Subset` |
| ![](http://matplotlib.org/_images/mathmpl/math-191c6ba7fa.png) `\Supset` | ![](http://matplotlib.org/_images/mathmpl/math-219444d8f5.png) `\Vdash` | ![](http://matplotlib.org/_images/mathmpl/math-7db176731c.png) `\Vvdash` |
| ![](http://matplotlib.org/_images/mathmpl/math-c957a5ae9f.png) `\approx` | ![](http://matplotlib.org/_images/mathmpl/math-cf8f5e2275.png) `\approxeq` | ![](http://matplotlib.org/_images/mathmpl/math-4ea8b1e13e.png) `\ast` |
| ![](http://matplotlib.org/_images/mathmpl/math-23c4970a1a.png) `\asymp` | ![](http://matplotlib.org/_images/mathmpl/math-ea0303ad72.png) `\backepsilon` | ![](http://matplotlib.org/_images/mathmpl/math-b1d77626bb.png) `\backsim` |
| ![](http://matplotlib.org/_images/mathmpl/math-af3bc8ac21.png) `\backsimeq` | ![](http://matplotlib.org/_images/mathmpl/math-71771b9385.png) `\barwedge` | ![](http://matplotlib.org/_images/mathmpl/math-937e2c148d.png) `\because` |
| ![](http://matplotlib.org/_images/mathmpl/math-51ae43b24b.png) `\between` | ![](http://matplotlib.org/_images/mathmpl/math-3b72c12de0.png) `\bigcirc` | ![](http://matplotlib.org/_images/mathmpl/math-e98739824f.png) `\bigtriangledown` |
| ![](http://matplotlib.org/_images/mathmpl/math-52ddd6655e.png) `\bigtriangleup` | ![](http://matplotlib.org/_images/mathmpl/math-679967c920.png) `\blacktriangleleft` | ![](http://matplotlib.org/_images/mathmpl/math-2ff97d8581.png) `\blacktriangleright` |
| ![](http://matplotlib.org/_images/mathmpl/math-d2bc160257.png) `\bot` | ![](http://matplotlib.org/_images/mathmpl/math-88c0703f35.png) `\bowtie` | ![](http://matplotlib.org/_images/mathmpl/math-0cc3cb6c41.png) `\boxdot` |
| ![](http://matplotlib.org/_images/mathmpl/math-b5a379f4e8.png) `\boxminus` | ![](http://matplotlib.org/_images/mathmpl/math-3e25be9041.png) `\boxplus` | ![](http://matplotlib.org/_images/mathmpl/math-d3219d7443.png) `\boxtimes` |
| ![](http://matplotlib.org/_images/mathmpl/math-ef7a046183.png) `\bullet` | ![](http://matplotlib.org/_images/mathmpl/math-c5baac4e57.png) `\bumpeq` | ![](http://matplotlib.org/_images/mathmpl/math-f0c7f8f01c.png) `\cap` |
| ![](http://matplotlib.org/_images/mathmpl/math-5a90bc5099.png) `\cdot` | ![](http://matplotlib.org/_images/mathmpl/math-f9b0df773f.png) `\circ` | ![](http://matplotlib.org/_images/mathmpl/math-5af298e692.png) `\circeq` |
| ![](http://matplotlib.org/_images/mathmpl/math-e4d9d4c64b.png) `\coloneq` | ![](http://matplotlib.org/_images/mathmpl/math-b43c061111.png) `\cong` | ![](http://matplotlib.org/_images/mathmpl/math-20b287ac85.png) `\cup` |
| ![](http://matplotlib.org/_images/mathmpl/math-c0df1e9b19.png) `\curlyeqprec` | ![](http://matplotlib.org/_images/mathmpl/math-995f666935.png) `\curlyeqsucc` | ![](http://matplotlib.org/_images/mathmpl/math-615de138a6.png) `\curlyvee` |
| ![](http://matplotlib.org/_images/mathmpl/math-5af1fa6042.png) `\curlywedge` | ![](http://matplotlib.org/_images/mathmpl/math-9b12241d0c.png) `\dag` | ![](http://matplotlib.org/_images/mathmpl/math-9e1beabce9.png) `\dashv` |
| ![](http://matplotlib.org/_images/mathmpl/math-f0fa40854a.png) `\ddag` | ![](http://matplotlib.org/_images/mathmpl/math-765d4eae57.png) `\diamond` | ![](http://matplotlib.org/_images/mathmpl/math-a1903b29fd.png) `\div` |
| ![](http://matplotlib.org/_images/mathmpl/math-3df678db55.png) `\divideontimes` | ![](http://matplotlib.org/_images/mathmpl/math-a5b22dbdac.png) `\doteq` | ![](http://matplotlib.org/_images/mathmpl/math-ff23293ae5.png) `\doteqdot` |
| ![](http://matplotlib.org/_images/mathmpl/math-397b5fc155.png) `\dotplus` | ![](http://matplotlib.org/_images/mathmpl/math-d5242ce585.png) `\doublebarwedge` | ![](http://matplotlib.org/_images/mathmpl/math-a4f1a69c76.png) `\eqcirc` |
| ![](http://matplotlib.org/_images/mathmpl/math-17826fcd24.png) `\eqcolon` | ![](http://matplotlib.org/_images/mathmpl/math-c104febab3.png) `\eqsim` | ![](http://matplotlib.org/_images/mathmpl/math-45eaae26d2.png) `\eqslantgtr` |
| ![](http://matplotlib.org/_images/mathmpl/math-c3fea548da.png) `\eqslantless` | ![](http://matplotlib.org/_images/mathmpl/math-cc1340c453.png) `\equiv` | ![](http://matplotlib.org/_images/mathmpl/math-7965c0c1af.png) `\fallingdotseq` |
| ![](http://matplotlib.org/_images/mathmpl/math-a41c184ca6.png) `\frown` | ![](http://matplotlib.org/_images/mathmpl/math-0bf42a25bb.png) `\geq` | ![](http://matplotlib.org/_images/mathmpl/math-9b14251f65.png) `\geqq` |
| ![](http://matplotlib.org/_images/mathmpl/math-1fca7a951f.png) `\geqslant` | ![](http://matplotlib.org/_images/mathmpl/math-f9990bc9cf.png) `\gg` | ![](http://matplotlib.org/_images/mathmpl/math-a3de1e5b51.png) `\ggg` |
| ![](http://matplotlib.org/_images/mathmpl/math-04c47dcb6e.png) `\gnapprox` | ![](http://matplotlib.org/_images/mathmpl/math-a3f9f1f014.png) `\gneqq` | ![](http://matplotlib.org/_images/mathmpl/math-793d9cedd0.png) `\gnsim` |
| ![](http://matplotlib.org/_images/mathmpl/math-207852189a.png) `\gtrapprox` | ![](http://matplotlib.org/_images/mathmpl/math-9336896bb3.png) `\gtrdot` | ![](http://matplotlib.org/_images/mathmpl/math-4cd21f8ba6.png) `\gtreqless` |
| ![](http://matplotlib.org/_images/mathmpl/math-18a0084a2d.png) `\gtreqqless` | ![](http://matplotlib.org/_images/mathmpl/math-8e388594ad.png) `\gtrless` | ![](http://matplotlib.org/_images/mathmpl/math-9d5e427aeb.png) `\gtrsim` |
| ![](http://matplotlib.org/_images/mathmpl/math-58e3fcf6fd.png) `\in` | ![](http://matplotlib.org/_images/mathmpl/math-0e049fe80b.png) `\intercal` | ![](http://matplotlib.org/_images/mathmpl/math-1a503a50f2.png) `\leftthreetimes` |
| ![](http://matplotlib.org/_images/mathmpl/math-aca311c641.png) `\leq` | ![](http://matplotlib.org/_images/mathmpl/math-d87b34b699.png) `\leqq` | ![](http://matplotlib.org/_images/mathmpl/math-764751dad5.png) `\leqslant` |
| ![](http://matplotlib.org/_images/mathmpl/math-b8571a3cc2.png) `\lessapprox` | ![](http://matplotlib.org/_images/mathmpl/math-6cb5c3c310.png) `\lessdot` | ![](http://matplotlib.org/_images/mathmpl/math-1632a38331.png) `\lesseqgtr` |
| ![](http://matplotlib.org/_images/mathmpl/math-d367d088c6.png) `\lesseqqgtr` | ![](http://matplotlib.org/_images/mathmpl/math-268c486057.png) `\lessgtr` | ![](http://matplotlib.org/_images/mathmpl/math-b53ab799d1.png) `\lesssim` |
| ![](http://matplotlib.org/_images/mathmpl/math-f5e02865f3.png) `\ll` | ![](http://matplotlib.org/_images/mathmpl/math-2303518311.png) `\lll` | ![](http://matplotlib.org/_images/mathmpl/math-c408639f33.png) `\lnapprox` |
| ![](http://matplotlib.org/_images/mathmpl/math-38bf4cf10d.png) `\lneqq` | ![](http://matplotlib.org/_images/mathmpl/math-ad67ff4a6f.png) `\lnsim` | ![](http://matplotlib.org/_images/mathmpl/math-f557917efd.png) `\ltimes` |
| ![](http://matplotlib.org/_images/mathmpl/math-96c9a8ca95.png) `\mid` | ![](http://matplotlib.org/_images/mathmpl/math-b5ae8c62a3.png) `\models` | ![](http://matplotlib.org/_images/mathmpl/math-608c4a02ea.png) `\mp` |
| ![](http://matplotlib.org/_images/mathmpl/math-e0ca686f62.png) `\nVDash` | ![](http://matplotlib.org/_images/mathmpl/math-4d5d5f4ffb.png) `\nVdash` | ![](http://matplotlib.org/_images/mathmpl/math-8aa32761da.png) `\napprox` |
| ![](http://matplotlib.org/_images/mathmpl/math-92306485fb.png) `\ncong` | ![](http://matplotlib.org/_images/mathmpl/math-6e6c5971ad.png) `\ne` | ![](http://matplotlib.org/_images/mathmpl/math-da1122f776.png) `\neq` |
| ![](http://matplotlib.org/_images/mathmpl/math-da1122f776.png) `\neq` | ![](http://matplotlib.org/_images/mathmpl/math-989088989a.png) `\nequiv` | ![](http://matplotlib.org/_images/mathmpl/math-07c03ece9c.png) `\ngeq` |
| ![](http://matplotlib.org/_images/mathmpl/math-c2c43a5762.png) `\ngtr` | ![](http://matplotlib.org/_images/mathmpl/math-7e90b124a8.png) `\ni` | ![](http://matplotlib.org/_images/mathmpl/math-1c2ed5670a.png) `\nleq` |
| ![](http://matplotlib.org/_images/mathmpl/math-c9136df47e.png) `\nless` | ![](http://matplotlib.org/_images/mathmpl/math-4c5d76f523.png) `\nmid` | ![](http://matplotlib.org/_images/mathmpl/math-9afe2d20f8.png) `\notin` |
| ![](http://matplotlib.org/_images/mathmpl/math-e63a2108d5.png) `\nparallel` | ![](http://matplotlib.org/_images/mathmpl/math-201b65e42c.png) `\nprec` | ![](http://matplotlib.org/_images/mathmpl/math-37454f1e25.png) `\nsim` |
| ![](http://matplotlib.org/_images/mathmpl/math-b045970090.png) `\nsubset` | ![](http://matplotlib.org/_images/mathmpl/math-e2dcef116c.png) `\nsubseteq` | ![](http://matplotlib.org/_images/mathmpl/math-0dc1c96f16.png) `\nsucc` |
| ![](http://matplotlib.org/_images/mathmpl/math-0d1363d575.png) `\nsupset` | ![](http://matplotlib.org/_images/mathmpl/math-8963eae853.png) `\nsupseteq` | ![](http://matplotlib.org/_images/mathmpl/math-2eaa265b46.png) `\ntriangleleft` |
| ![](http://matplotlib.org/_images/mathmpl/math-343170b287.png) `\ntrianglelefteq` | ![](http://matplotlib.org/_images/mathmpl/math-813dcf0a93.png) `\ntriangleright` | ![](http://matplotlib.org/_images/mathmpl/math-df6899ad3e.png) `\ntrianglerighteq` |
| ![](http://matplotlib.org/_images/mathmpl/math-a55f718abe.png) `\nvDash` | ![](http://matplotlib.org/_images/mathmpl/math-fefbb15af0.png) `\nvdash` | ![](http://matplotlib.org/_images/mathmpl/math-b8348856ea.png) `\odot` |
| ![](http://matplotlib.org/_images/mathmpl/math-497b831b05.png) `\ominus` | ![](http://matplotlib.org/_images/mathmpl/math-cfcebc2ef8.png) `\oplus` | ![](http://matplotlib.org/_images/mathmpl/math-6fd5eead33.png) `\oslash` |
| ![](http://matplotlib.org/_images/mathmpl/math-3d7ac4bb5c.png) `\otimes` | ![](http://matplotlib.org/_images/mathmpl/math-305e05a6ab.png) `\parallel` | ![](http://matplotlib.org/_images/mathmpl/math-86ea2beb93.png) `\perp` |
| ![](http://matplotlib.org/_images/mathmpl/math-62d5e1ef75.png) `\pitchfork` | ![](http://matplotlib.org/_images/mathmpl/math-813255d42d.png) `\pm` | ![](http://matplotlib.org/_images/mathmpl/math-2a54002803.png) `\prec` |
| ![](http://matplotlib.org/_images/mathmpl/math-6f127405a3.png) `\precapprox` | ![](http://matplotlib.org/_images/mathmpl/math-5686c5a93f.png) `\preccurlyeq` | ![](http://matplotlib.org/_images/mathmpl/math-c6975aea0e.png) `\preceq` |
| ![](http://matplotlib.org/_images/mathmpl/math-53e4edd44d.png) `\precnapprox` | ![](http://matplotlib.org/_images/mathmpl/math-b7c281dd54.png) `\precnsim` | ![](http://matplotlib.org/_images/mathmpl/math-58f182e47e.png) `\precsim` |
| ![](http://matplotlib.org/_images/mathmpl/math-4225d47da8.png) `\propto` | ![](http://matplotlib.org/_images/mathmpl/math-03cbb97a54.png) `\rightthreetimes` | ![](http://matplotlib.org/_images/mathmpl/math-8f609835cb.png) `\risingdotseq` |
| ![](http://matplotlib.org/_images/mathmpl/math-61a5f3fde0.png) `\rtimes` | ![](http://matplotlib.org/_images/mathmpl/math-10ab63f88f.png) `\sim` | ![](http://matplotlib.org/_images/mathmpl/math-f5e3901a47.png) `\simeq` |
| ![](http://matplotlib.org/_images/mathmpl/math-cd5adea2d9.png) `\slash` | ![](http://matplotlib.org/_images/mathmpl/math-11c6bdf228.png) `\smile` | ![](http://matplotlib.org/_images/mathmpl/math-2fc0f7c957.png) `\sqcap` |
| ![](http://matplotlib.org/_images/mathmpl/math-f3f9a5c2b6.png) `\sqcup` | ![](http://matplotlib.org/_images/mathmpl/math-32710445c4.png) `\sqsubset` | ![](http://matplotlib.org/_images/mathmpl/math-32710445c4.png) `\sqsubset` |
| ![](http://matplotlib.org/_images/mathmpl/math-6462f633f1.png) `\sqsubseteq` | ![](http://matplotlib.org/_images/mathmpl/math-b373234f3b.png) `\sqsupset` | ![](http://matplotlib.org/_images/mathmpl/math-b373234f3b.png) `\sqsupset` |
| ![](http://matplotlib.org/_images/mathmpl/math-301349a96f.png) `\sqsupseteq` | ![](http://matplotlib.org/_images/mathmpl/math-3ea081f1d9.png) `\star` | ![](http://matplotlib.org/_images/mathmpl/math-d7ee7c1348.png) `\subset` |
| ![](http://matplotlib.org/_images/mathmpl/math-ab35a80a37.png) `\subseteq` | ![](http://matplotlib.org/_images/mathmpl/math-329584d288.png) `\subseteqq` | ![](http://matplotlib.org/_images/mathmpl/math-26f9e5316b.png) `\subsetneq` |
| ![](http://matplotlib.org/_images/mathmpl/math-d6c1dc73f3.png) `\subsetneqq` | ![](http://matplotlib.org/_images/mathmpl/math-3b5db3b36b.png) `\succ` | ![](http://matplotlib.org/_images/mathmpl/math-29a7c6603c.png) `\succapprox` |
| ![](http://matplotlib.org/_images/mathmpl/math-764af5d0f7.png) `\succcurlyeq` | ![](http://matplotlib.org/_images/mathmpl/math-f083286645.png) `\succeq` | ![](http://matplotlib.org/_images/mathmpl/math-12e9272240.png) `\succnapprox` |
| ![](http://matplotlib.org/_images/mathmpl/math-22a812f02e.png) `\succnsim` | ![](http://matplotlib.org/_images/mathmpl/math-f313a5f9af.png) `\succsim` | ![](http://matplotlib.org/_images/mathmpl/math-7a88315c05.png) `\supset` |
| ![](http://matplotlib.org/_images/mathmpl/math-b15f9f29ec.png) `\supseteq` | ![](http://matplotlib.org/_images/mathmpl/math-2b42f15859.png) `\supseteqq` | ![](http://matplotlib.org/_images/mathmpl/math-0ebac5d490.png) `\supsetneq` |
| ![](http://matplotlib.org/_images/mathmpl/math-7cafbba6d3.png) `\supsetneqq` | ![](http://matplotlib.org/_images/mathmpl/math-21e977e4ec.png) `\therefore` | ![](http://matplotlib.org/_images/mathmpl/math-ae7023d9db.png) `\times` |
| ![](http://matplotlib.org/_images/mathmpl/math-f0fe2a4a9f.png) `\top` | ![](http://matplotlib.org/_images/mathmpl/math-7a5bdaf004.png) `\triangleleft` | ![](http://matplotlib.org/_images/mathmpl/math-3234da3142.png) `\trianglelefteq` |
| ![](http://matplotlib.org/_images/mathmpl/math-5325d825f0.png) `\triangleq` | ![](http://matplotlib.org/_images/mathmpl/math-61187783ee.png) `\triangleright` | ![](http://matplotlib.org/_images/mathmpl/math-229058201e.png) `\trianglerighteq` |
| ![](http://matplotlib.org/_images/mathmpl/math-8c6a0f04b9.png) `\uplus` | ![](http://matplotlib.org/_images/mathmpl/math-8da9245788.png) `\vDash` | ![](http://matplotlib.org/_images/mathmpl/math-7450111856.png) `\varpropto` |
| ![](http://matplotlib.org/_images/mathmpl/math-311d2647c5.png) `\vartriangleleft` | ![](http://matplotlib.org/_images/mathmpl/math-7da885dcbf.png) `\vartriangleright` | ![](http://matplotlib.org/_images/mathmpl/math-d8ad6ecbe6.png) `\vdash` |
| ![](http://matplotlib.org/_images/mathmpl/math-f5af631a03.png) `\vee` | ![](http://matplotlib.org/_images/mathmpl/math-0ca72c02e5.png) `\veebar` | ![](http://matplotlib.org/_images/mathmpl/math-4c229f580d.png) `\wedge` |
| ![](http://matplotlib.org/_images/mathmpl/math-953993beed.png) `\wr` |

| 箭头符号 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-0c8ba18b43.png) `\Downarrow` | ![](http://matplotlib.org/_images/mathmpl/math-1a6ec6d88f.png) `\Leftarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-74b9b263f9.png) `\Leftrightarrow` | ![](http://matplotlib.org/_images/mathmpl/math-3ce6141dea.png) `\Lleftarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-e3d8965f58.png) `\Longleftarrow` | ![](http://matplotlib.org/_images/mathmpl/math-eb3a880058.png) `\Longleftrightarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-c985be990e.png) `\Longrightarrow` | ![](http://matplotlib.org/_images/mathmpl/math-459d7c5693.png) `\Lsh` |
| ![](http://matplotlib.org/_images/mathmpl/math-0f08e28a07.png) `\Nearrow` | ![](http://matplotlib.org/_images/mathmpl/math-a608a7ae83.png) `\Nwarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-5e42a40994.png) `\Rightarrow` | ![](http://matplotlib.org/_images/mathmpl/math-317920b703.png) `\Rrightarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-26fab8f44f.png) `\Rsh` | ![](http://matplotlib.org/_images/mathmpl/math-ba64c5e997.png) `\Searrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-6722d13e60.png) `\Swarrow` | ![](http://matplotlib.org/_images/mathmpl/math-d00ab41d80.png) `\Uparrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-94ff64057f.png) `\Updownarrow` | ![](http://matplotlib.org/_images/mathmpl/math-a59e0fa5ee.png) `\circlearrowleft` |
| ![](http://matplotlib.org/_images/mathmpl/math-ea5765e8b3.png) `\circlearrowright` | ![](http://matplotlib.org/_images/mathmpl/math-68b96a49a5.png) `\curvearrowleft` |
| ![](http://matplotlib.org/_images/mathmpl/math-eb8d6ee4ad.png) `\curvearrowright` | ![](http://matplotlib.org/_images/mathmpl/math-682a5688ef.png) `\dashleftarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-8bc070eada.png) `\dashrightarrow` | ![](http://matplotlib.org/_images/mathmpl/math-56b7078922.png) `\downarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-1d11ce50b2.png) `\downdownarrows` | ![](http://matplotlib.org/_images/mathmpl/math-a019dc17a7.png) `\downharpoonleft` |
| ![](http://matplotlib.org/_images/mathmpl/math-16b15cdedd.png) `\downharpoonright` | ![](http://matplotlib.org/_images/mathmpl/math-3db5c70042.png) `\hookleftarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-580fac9571.png) `\hookrightarrow` | ![](http://matplotlib.org/_images/mathmpl/math-09e354a93e.png) `\leadsto` |
| ![](http://matplotlib.org/_images/mathmpl/math-097464d1cd.png) `\leftarrow` | ![](http://matplotlib.org/_images/mathmpl/math-a2e07eb2ff.png) `\leftarrowtail` |
| ![](http://matplotlib.org/_images/mathmpl/math-792b216977.png) `\leftharpoondown` | ![](http://matplotlib.org/_images/mathmpl/math-3c072a15c0.png) `\leftharpoonup` |
| ![](http://matplotlib.org/_images/mathmpl/math-433174617c.png) `\leftleftarrows` | ![](http://matplotlib.org/_images/mathmpl/math-bce42da457.png) `\leftrightarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-dec391be07.png) `\leftrightarrows` | ![](http://matplotlib.org/_images/mathmpl/math-8c68333295.png) `\leftrightharpoons` |
| ![](http://matplotlib.org/_images/mathmpl/math-1afd9d2af0.png) `\leftrightsquigarrow` | ![](http://matplotlib.org/_images/mathmpl/math-0a36be904f.png) `\leftsquigarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-c8fe9fb96c.png) `\longleftarrow` | ![](http://matplotlib.org/_images/mathmpl/math-91b94c6be9.png) `\longleftrightarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-02ce986a2e.png) `\longmapsto` | ![](http://matplotlib.org/_images/mathmpl/math-80a13771b7.png) `\longrightarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-3bfe8e8950.png) `\looparrowleft` | ![](http://matplotlib.org/_images/mathmpl/math-64aa42214e.png) `\looparrowright` |
| ![](http://matplotlib.org/_images/mathmpl/math-9a483a288a.png) `\mapsto` | ![](http://matplotlib.org/_images/mathmpl/math-c40f3bc7dc.png) `\multimap` |
| ![](http://matplotlib.org/_images/mathmpl/math-ea5241d5f2.png) `\nLeftarrow` | ![](http://matplotlib.org/_images/mathmpl/math-9119a30630.png) `\nLeftrightarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-eeabc86e5f.png) `\nRightarrow` | ![](http://matplotlib.org/_images/mathmpl/math-640fa94ebe.png) `\nearrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-f9cc3f8904.png) `\nleftarrow` | ![](http://matplotlib.org/_images/mathmpl/math-1278a024c8.png) `\nleftrightarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-f11a3eab57.png) `\nrightarrow` | ![](http://matplotlib.org/_images/mathmpl/math-3223454152.png) `\nwarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-fb1cbbd43f.png) `\rightarrow` | ![](http://matplotlib.org/_images/mathmpl/math-2e03b9e387.png) `\rightarrowtail` |
| ![](http://matplotlib.org/_images/mathmpl/math-41f636a823.png) `\rightharpoondown` | ![](http://matplotlib.org/_images/mathmpl/math-2cdbf2db88.png) `\rightharpoonup` |
| ![](http://matplotlib.org/_images/mathmpl/math-2617106b1e.png) `\rightleftarrows` | ![](http://matplotlib.org/_images/mathmpl/math-2617106b1e.png) `\rightleftarrows` |
| ![](http://matplotlib.org/_images/mathmpl/math-a2eb9bae76.png) `\rightleftharpoons` | ![](http://matplotlib.org/_images/mathmpl/math-a2eb9bae76.png) `\rightleftharpoons` |
| ![](http://matplotlib.org/_images/mathmpl/math-43575c473c.png) `\rightrightarrows` | ![](http://matplotlib.org/_images/mathmpl/math-43575c473c.png) `\rightrightarrows` |
| ![](http://matplotlib.org/_images/mathmpl/math-2aff52a07e.png) `\rightsquigarrow` | ![](http://matplotlib.org/_images/mathmpl/math-93a935b705.png) `\searrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-8d37bd9196.png) `\swarrow` | ![](http://matplotlib.org/_images/mathmpl/math-306ea70acd.png) `\to` |
| ![](http://matplotlib.org/_images/mathmpl/math-ae2fa40b25.png) `\twoheadleftarrow` | ![](http://matplotlib.org/_images/mathmpl/math-8e6cdc7038.png) `\twoheadrightarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-f1bfb0bbf7.png) `\uparrow` | ![](http://matplotlib.org/_images/mathmpl/math-eb3b3a6d5c.png) `\updownarrow` |
| ![](http://matplotlib.org/_images/mathmpl/math-eb3b3a6d5c.png) `\updownarrow` | ![](http://matplotlib.org/_images/mathmpl/math-bbdf3d8983.png) `\upharpoonleft` |
| ![](http://matplotlib.org/_images/mathmpl/math-5fea7c5657.png) `\upharpoonright` | ![](http://matplotlib.org/_images/mathmpl/math-d831d8aa62.png) `\upuparrows` |


| 杂项符号 | | |
| --- | --- | --- |
| ![](http://matplotlib.org/_images/mathmpl/math-390d3dc75c.png) `\$` | ![](http://matplotlib.org/_images/mathmpl/math-7ffb7d798c.png) `\AA` | ![](http://matplotlib.org/_images/mathmpl/math-38501d21c9.png) `\Finv` |
| ![](http://matplotlib.org/_images/mathmpl/math-be84d4168e.png) `\Game` | ![](http://matplotlib.org/_images/mathmpl/math-3207fff524.png) `\Im` | ![](http://matplotlib.org/_images/mathmpl/math-482297a060.png) `\P` |
| ![](http://matplotlib.org/_images/mathmpl/math-6ea3150bfd.png) `\Re` | ![](http://matplotlib.org/_images/mathmpl/math-a99c89f6e1.png) `\S` | ![](http://matplotlib.org/_images/mathmpl/math-2fcd70072d.png) `\angle` |
| ![](http://matplotlib.org/_images/mathmpl/math-9db5c962c8.png) `\backprime` | ![](http://matplotlib.org/_images/mathmpl/math-8082fb34e8.png) `\bigstar` | ![](http://matplotlib.org/_images/mathmpl/math-4b07b72122.png) `\blacksquare` |
| ![](http://matplotlib.org/_images/mathmpl/math-8f8c0c020c.png) `\blacktriangle` | ![](http://matplotlib.org/_images/mathmpl/math-58162c32f0.png) `\blacktriangledown` | ![](http://matplotlib.org/_images/mathmpl/math-e90d63d41d.png) `\cdots` |
| ![](http://matplotlib.org/_images/mathmpl/math-800bb70468.png) `\checkmark` | ![](http://matplotlib.org/_images/mathmpl/math-762c3b5e9e.png) `\circledR` | ![](http://matplotlib.org/_images/mathmpl/math-52eae78384.png) `\circledS` |
| ![](http://matplotlib.org/_images/mathmpl/math-4d24dff6f8.png) `\clubsuit` | ![](http://matplotlib.org/_images/mathmpl/math-b225b29af4.png) `\complement` | ![](http://matplotlib.org/_images/mathmpl/math-8f454df900.png) `\copyright` |
| ![](http://matplotlib.org/_images/mathmpl/math-dbcc77f1d2.png) `\ddots` | ![](http://matplotlib.org/_images/mathmpl/math-bc54d541fc.png) `\diamondsuit` | ![](http://matplotlib.org/_images/mathmpl/math-923c665edb.png) `\ell` |
| ![](http://matplotlib.org/_images/mathmpl/math-51cd44e108.png) `\emptyset` | ![](http://matplotlib.org/_images/mathmpl/math-19f957fc71.png) `\eth` | ![](http://matplotlib.org/_images/mathmpl/math-cac5abe8bf.png) `\exists` |
| ![](http://matplotlib.org/_images/mathmpl/math-518af824c6.png) `\flat` | ![](http://matplotlib.org/_images/mathmpl/math-92a896986d.png) `\forall` | ![](http://matplotlib.org/_images/mathmpl/math-2525d5d71d.png) `\hbar` |
| ![](http://matplotlib.org/_images/mathmpl/math-eab5c7cdff.png) `\heartsuit` | ![](http://matplotlib.org/_images/mathmpl/math-dcb2243778.png) `\hslash` | ![](http://matplotlib.org/_images/mathmpl/math-f8daa97519.png) `\iiint` |
| ![](http://matplotlib.org/_images/mathmpl/math-14a5baf1f1.png) `\iint` | ![](http://matplotlib.org/_images/mathmpl/math-14a5baf1f1.png) `\iint` | ![](http://matplotlib.org/_images/mathmpl/math-6a5f1c0ebd.png) `\imath` |
| ![](http://matplotlib.org/_images/mathmpl/math-c899412e92.png) `\infty` | ![](http://matplotlib.org/_images/mathmpl/math-cca8605565.png) `\jmath` | ![](http://matplotlib.org/_images/mathmpl/math-ee226905c4.png) `\ldots` |
| ![](http://matplotlib.org/_images/mathmpl/math-d78cd804a4.png) `\measuredangle` | ![](http://matplotlib.org/_images/mathmpl/math-07933b21e0.png) `\natural` | ![](http://matplotlib.org/_images/mathmpl/math-21d4b9ec5e.png) `\neg` |
| ![](http://matplotlib.org/_images/mathmpl/math-a01094061c.png) `\nexists` | ![](http://matplotlib.org/_images/mathmpl/math-fea35fa8ec.png) `\oiiint` | ![](http://matplotlib.org/_images/mathmpl/math-7d9222c03b.png) `\partial` |
| ![](http://matplotlib.org/_images/mathmpl/math-d4d8611cbc.png) `\prime` | ![](http://matplotlib.org/_images/mathmpl/math-0525bc07de.png) `\sharp` | ![](http://matplotlib.org/_images/mathmpl/math-799e766e98.png) `\spadesuit` |
| ![](http://matplotlib.org/_images/mathmpl/math-96aad37e82.png) `\sphericalangle` | ![](http://matplotlib.org/_images/mathmpl/math-e51ac520e2.png) `\ss` | ![](http://matplotlib.org/_images/mathmpl/math-62e1ea5660.png) `\triangledown` |
| ![](http://matplotlib.org/_images/mathmpl/math-91a36bab96.png) `\varnothing` | ![](http://matplotlib.org/_images/mathmpl/math-449680794f.png) `\vartriangle` | ![](http://matplotlib.org/_images/mathmpl/math-0716fbd542.png) `\vdots` |
| ![](http://matplotlib.org/_images/mathmpl/math-6eca465169.png) `\wp` | ![](http://matplotlib.org/_images/mathmpl/math-12713adf78.png) `\yen` |

如果特定符号没有名称（对于 STIX 字体中的许多较为模糊的符号也是如此），也可以使用 Unicode 字符：

```py
ur'$\u23ce$'
```

### 示例

下面是个示例，在上下文中展示了许多这些特性。

```py
import numpy as np
import matplotlib.pyplot as plt
t = np.arange(0.0, 2.0, 0.01)
s = np.sin(2*np.pi*t)

plt.plot(t,s)
plt.title(r'$\alpha_i > \beta_i$', fontsize=20)
plt.text(1, -0.6, r'$\sum_{i=0}^\infty x_i$', fontsize=20)
plt.text(0.6, 0.6, r'$\mathcal{A}\mathrm{sin}(2 \omega t)$',
         fontsize=20)
plt.xlabel('time (s)')
plt.ylabel('volts (mV)')
plt.show()
```

![](http://matplotlib.org/_images/pyplot_mathtext.png)

